@@ -1,6 +1,6 @@
-#! /usr/lib/veetest/veetest -d /usr/lib/veetest -r
-(revision "A.00.00")
-(date "Wed 10/Apr/1991")
+#! /usr/lib/veetest/veetest -r
+(revision "A.00.01")
+(date "Mon 23/Sep/1991")
 (component 0 "Context"
  (name "Digital Filter Example")
  (interface
@@ -35,7 +35,7 @@
    (views
     (icon
      (extent 163 0)
-     (iconImage display.icon)
+     (iconImage "display.icon")
     )
     (detail
      (origin 548 258)
@@ -46,22 +46,22 @@
      (scale 0
       (name "Mag")
       (domainName "Freq")
-      (color 0x909090)
+      (pen 9)
       (show 1)
       (range 0 180 4 linear)
      )
      (domain 0 7000 4 linear)
      (trace 0 onScale 0
       (name "original")
-      (color 0xccff)
-      (lineType 3)
-      (pointType 0)
+      (pen 4)
+      (lineType 1)
+      (pointType 5)
      )
      (trace 1 onScale 0
       (name "filtered")
-      (color 0xffdd00)
+      (pen 7)
       (lineType 1)
-      (pointType 0)
+      (pointType 5)
      )
     )
     (active detail)
@@ -91,7 +91,168 @@
     (active detail)
    )
   )
-  (component 2 "ShiftRegister"
+  (component 2 "Formula"
+   (name " + ")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "X")
+     (lock name constraints)
+    )
+    (input 2
+     (type data)
+     (name "Y")
+     (lock name constraints)
+    )
+    (output 1
+     (type data)
+     (name "Result")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component isLocked yes)
+    (component expr 1 "X+Y")
+   )
+   (views
+    (icon
+     (origin 427 398)
+     (extent 46 25)
+    )
+    (detail
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 3 "ToWaveform"
+   (name "Build Waveform")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Array")
+     (tag "Array")
+     (requires
+      (datatype Real)
+     )
+     (lock name constraints)
+    )
+    (output 1
+     (type data)
+     (name "Wf")
+     (tag "Wf")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component interval 0.02)
+   )
+   (views
+    (icon
+     (origin 392 498)
+     (extent 136 64)
+     (iconImage "build.icon")
+    )
+    (detail
+     (origin 918 253)
+     (extent 212 54)
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 4 "Formula"
+   (name "poles")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "z1")
+     (optional yes)
+    )
+    (input 2
+     (type data)
+     (name "z2")
+     (optional yes)
+    )
+    (input 3
+     (type data)
+     (name "z3")
+     (optional yes)
+    )
+    (input 4
+     (type data)
+     (name "a")
+     (optional yes)
+    )
+    (output 1
+     (type data)
+     (name "Result")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component isLocked no)
+    (component expr 1 "a[1]*z1+a[2]*z2+a[3]*z3")
+   )
+   (views
+    (icon
+     (origin 281 388)
+     (extent 78 64)
+     (iconImage "/usr/lib/veetest/bitmaps/formula.icon")
+    )
+    (detail
+     (origin 225 528)
+     (extent 241 204)
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 5 "Start"
+   (name "Start")
+   (interface
+    (sequence out)
+   )
+   (implementation
+   )
+   (views
+    (icon
+     (origin 46 99)
+     (extent 109 82)
+    )
+    (detail
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 6 "ExitProcess"
+   (interface
+    (sequence in)
+   )
+   (implementation
+    (comp code 0)
+   )
+   (views
+    (icon
+     (origin 731 658)
+     (extent 78 64)
+     (iconImage "stop.icon")
+    )
+    (detail
+     (origin 710 683)
+     (extent 120 34)
+    )
+    (active icon)
+   )
+  )
+  (component 7 "ShiftRegister"
    (name "Shift Register")
    (interface
     (sequence in)
@@ -124,8 +285,8 @@
    )
    (views
     (icon
-     (origin 37 402)
-     (extent 147 77)
+     (origin 35 387)
+     (extent 150 46)
     )
     (detail
      (origin 195 590)
@@ -135,7 +296,7 @@
     (active icon)
    )
   )
-  (component 3 "Constant"
+  (component 8 "Constant"
    (name "a[k]")
    (interface
     (sequence in)
@@ -163,53 +324,17 @@
    )
    (views
     (icon
-     (origin 47 518)
+     (origin 67 518)
      (extent 46 25)
     )
     (detail
-     (origin 122 570)
-     (extent 217 100)
+     (origin 27 476)
+     (extent 167 88)
     )
-    (active icon)
+    (active detail)
    )
   )
-  (component 4 "Formula"
-   (name " + ")
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "X")
-     (lock name constraints)
-    )
-    (input 2
-     (type data)
-     (name "Y")
-     (lock name constraints)
-    )
-    (output 1
-     (type data)
-     (name "Result")
-     (lock name constraints)
-    )
-   )
-   (implementation
-    (component isLocked yes)
-    (component expr 1 "X+Y")
-   )
-   (views
-    (icon
-     (origin 427 418)
-     (extent 46 25)
-    )
-    (detail
-    )
-    (terminals on)
-    (active icon)
-   )
-  )
-  (component 5 "Constant"
+  (component 9 "Constant"
    (name "b[k]")
    (interface
     (sequence in)
@@ -237,17 +362,17 @@
    )
    (views
     (icon
-     (origin 37 588)
+     (origin 77 618)
      (extent 46 25)
     )
     (detail
-     (origin 352 600)
-     (extent 237 100)
+     (origin 27 609)
+     (extent 166 82)
     )
-    (active icon)
+    (active detail)
    )
   )
-  (component 6 "Formula"
+  (component 10 "Formula"
    (name "zeros")
    (interface
     (sequence in)
@@ -289,9 +414,9 @@
    )
    (views
     (icon
-     (origin 151 558)
+     (origin 281 598)
      (extent 78 64)
-     (iconImage /usr/lib/veetest/bitmaps/formula.icon)
+     (iconImage "/usr/lib/veetest/bitmaps/formula.icon")
     )
     (detail
      (origin 423 473)
@@ -301,7 +426,7 @@
     (active icon)
    )
   )
-  (component 7 "SlidingWindow"
+  (component 11 "SlidingWindow"
    (name "Collector")
    (interface
     (sequence in)
@@ -330,7 +455,7 @@
    )
    (views
     (icon
-     (origin 255 578)
+     (origin 385 618)
      (extent 110 25)
     )
     (detail
@@ -341,248 +466,7 @@
     (active icon)
    )
   )
-  (component 8 "ToWaveform"
-   (name "Build Waveform")
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "Array")
-     (tag "Array")
-     (requires
-      (datatype Real)
-     )
-     (lock name constraints)
-    )
-    (output 1
-     (type data)
-     (name "Wf")
-     (tag "Wf")
-     (lock name constraints)
-    )
-   )
-   (implementation
-    (component interval 0.02)
-   )
-   (views
-    (icon
-     (origin 392 498)
-     (extent 136 64)
-     (iconImage build.icon)
-    )
-    (detail
-     (origin 918 253)
-     (extent 212 54)
-    )
-    (terminals on)
-    (active icon)
-   )
-  )
-  (component 9 "Formula"
-   (name "poles")
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "z1")
-     (optional yes)
-    )
-    (input 2
-     (type data)
-     (name "z2")
-     (optional yes)
-    )
-    (input 3
-     (type data)
-     (name "z3")
-     (optional yes)
-    )
-    (input 4
-     (type data)
-     (name "a")
-     (optional yes)
-    )
-    (output 1
-     (type data)
-     (name "Result")
-     (lock name constraints)
-    )
-   )
-   (implementation
-    (component isLocked no)
-    (component expr 1 "a[1]*z1+a[2]*z2+a[3]*z3")
-   )
-   (views
-    (icon
-     (origin 281 408)
-     (extent 78 64)
-     (iconImage /usr/lib/veetest/bitmaps/formula.icon)
-    )
-    (detail
-     (origin 225 528)
-     (extent 241 204)
-    )
-    (terminals on)
-    (active icon)
-   )
-  )
-  (component 10 "VFunctionGenerator"
-   (name "200Hz Square Wave")
-   (interface
-    (sequence in)
-    (sequence out)
-    (output 1
-     (type data)
-     (lock name constraints)
-    )
-   )
-   (implementation
-    (component function Square)
-    (component frequency 200)
-    (component amplitude 1)
-    (component dcOffset 0)
-    (component phaseShift 0)
-    (component numPoints 256)
-    (component interval 0.02)
-    (component degRad Deg)
-    (component errorOnAlias 1)
-   )
-   (views
-    (icon
-     (origin 9 288)
-     (extent 163 25)
-    )
-    (detail
-     (origin 31 441)
-     (extent 239 198)
-    )
-    (terminals on)
-    (active icon)
-   )
-  )
-  (component 11 "FromWaveform"
-   (name "UnBuild Waveform")
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "Wf Data")
-     (requires
-      (datatype Waveform)
-     )
-     (lock name constraints)
-    )
-    (output 1
-     (type data)
-     (name "Real Ary")
-     (lock name constraints)
-    )
-    (output 2
-     (type data)
-     (name "Interval")
-     (lock name constraints)
-    )
-   )
-   (implementation
-   )
-   (views
-    (icon
-     (origin 203 308)
-     (extent 154 25)
-    )
-    (detail
-     (origin 305 505)
-     (extent 80 70)
-    )
-    (terminals on)
-    (active icon)
-   )
-  )
-  (component 12 "Formula"
-   (name "x(n)")
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "A")
-     (optional yes)
-    )
-    (input 2
-     (type data)
-     (name "B")
-     (optional yes)
-    )
-    (output 1
-     (type data)
-     (name "Result")
-     (lock name constraints)
-    )
-   )
-   (implementation
-    (component isLocked no)
-    (component expr 1 "b[a]")
-   )
-   (views
-    (icon
-     (origin 387 308)
-     (extent 46 25)
-    )
-    (detail
-     (origin 467 408)
-     (extent 79 104)
-    )
-    (terminals on)
-    (active icon)
-   )
-  )
-  (component 13 "Start"
-   (name "Start")
-   (interface
-    (sequence out)
-   )
-   (implementation
-   )
-   (views
-    (icon
-     (origin 46 99)
-     (extent 109 82)
-    )
-    (detail
-    )
-    (terminals on)
-    (active icon)
-   )
-  )
-  (component 14 "ForCount"
-   (name "256 pts")
-   (interface
-    (sequence in)
-    (sequence out)
-    (output 1
-     (type data)
-     (lock name constraints)
-    )
-   )
-   (implementation
-    (component count 256)
-   )
-   (views
-    (icon
-     (origin 61 228)
-     (extent 78 25)
-    )
-    (detail
-     (origin 88 323)
-     (extent 165 34)
-    )
-    (active icon)
-   )
-  )
-  (component 15 "Context"
+  (component 12 "Context"
    (name "Press For")
    (interface
     (sequence in)
@@ -688,7 +572,7 @@
       (icon
        (origin 55 208)
        (extent 110 64)
-       (iconImage loop.icon)
+       (iconImage "loop.icon")
       )
       (detail
       )
@@ -736,50 +620,52 @@
        (interface
        )
        (implementation
-        (component text 43 9
-         PURPOSE:  To illustrate:
-          1. Unbuilding and building time domain waveforms.
-          2. Construction of a 3rd order elliptical digital filter.
-          3. Automatic conversion from the time domain to the frequency domain.
+        (component text 45 9
+         PURPOSE:      To illustrate:  1) Unbuilding and building time domain waveforms,
+                       2) Construction of a 3rd order elliptical digital filter, and
+                       3) Automatic conversion from the time domain to the frequency domain.
          
-         USER INPUT REQUIRED: None.  Click on "Start" to run the model.
+         USER INPUT REQUIRED: None.  Click on "Start" or "Run" to run the model.
          
          EXPLANATION:  A digital filter operates iteratively on a sequence of numbers.  The 
-          "For Count" object, "Formula" object  titled "x(n)", and "Unbuild Waveform" object
-          convert the output of the "Function Generator" (titled "200Hz Square Wave") to such
-          a sequence.  The "+" is given one number after another.
+                       For Count object, Formula object titled "x(n)", and Unbuild Waveform
+                       object convert the output of the "Function Generator" (titled "200Hz
+                       Square Wave") to such a sequence.  The "+" is given one number after
+                       another.
          
-          The output of the filter, which appears on the output of the "Formula" object titled
-          "zeros", is also a sequence of numbers.  The "Sliding Collector"  converts the
-          individual numbers into an array and the "Build Waveform" makes the array into a time
-          domain waveform similar to the output of the "Function Generator".
+                       The output of the filter, which appears on the output of the Formula
+                       object titled "zeros", is also a sequence of numbers.  The Sliding
+                       Collector converts the individual numbers into an array and the Build
+                       Waveform makes the array into a time domain waveform similar to the
+                       output of the Function Generator.
          
-          The digital filter is constructed with the  "Shift Register", "Formula" objects ("poles"
-          and "zeros"), addition object, and "Constant" objects ("a[k]" and "b[k]").  This filter
-          implements an arbitrary 3rd order digital filter of the form:
+                       The digital filter is constructed with the Shift Register, Formulas
+                       ("poles" and "zeros"), Addition and Constant objects ("a[k]" and "b[k]").
+                       This filter implements an arbitrary 3rd order digital filter of the form:
          
-                          -1     -2     -3
-                   b0+b1*z  +b2*z  +b3*z
-          H(z) = -------------------------
-                         -1     -2    -3
-                  1-(a1*z  +a2*z +a3*z  )
+                                        -1     -2     -3
+                                 b0+b1*z  +b2*z  +b3*z
+                        H(z) = -------------------------
+                                        -1     -2    -3
+                                 1-(a1*z  +a2*z +a3*z  )
          
-          The filter is implemented using direct form II. The coefficients of a 3rd order
-          elliptical filter were obtained from the book "Digital Signal Processing" by Alan V. 
-          Oppenheim and Ronald W.  Schafer, page 226.
+                       The filter is implemented using direct form II. The coefficients of a
+                       3rd order elliptical filter were obtained from the book "Digital Signal
+                       Processing" by Alan V. Oppenheim and Ronald W.  Schafer, page 226.
          
-          The result of the filtering operation can be seen in the display labeled "Elliptical
-          Filter".  While the inputs are time domain waveforms, the display is done in the
-          frequency domain.  The display automatically performs an fft on the input to change
-          domains.
+                       The result of the filtering operation can be seen in the display labeled
+                       "Elliptical Filter".  While the inputs are time domain waveforms, the
+                       display is done in the frequency domain.  The display automatically
+                       performs an FFT on the input to change domains.
          
-          Try changing the parameters of the square wave. If you know the coefficients for another
-          of 3rd order or less filter, try changing "a[k]" and "b[k]".  Try changing the display
-          to log or turn on markers.
+                       Try changing the parameters of the square wave. If you know the
+                       coefficients for another of 3rd order or less filter, try changing "a[k]"
+                       and "b[k]".  Try changing the display to log or turn on markers.
+         
+                       The order of the filter can be easily increased by adding outputs to the
+                       Shift Register, increasing the size of "a[k]" and "b[k]", and editing
+                       the formulas in the "poles" and "zeros" Formula objects. 
          
-          The order of the filter can be easily increased by adding outputs to the "Shift
-          Register", increasing the size of "a[k]" and "b[k]", and editing the formulas in
-          the "poles" and "zeros" "Formula" objects. 
         )
        )
        (views
@@ -810,7 +696,7 @@
         )
         (widget 1 detail
          (title off)
-         (origin 34 172)
+         (origin 34 173)
          (extent 835 461)
          (editing disabled)
         )
@@ -884,167 +770,330 @@
     (active panel)
    )
   )
+  (component 13 "ForCount"
+   (name "256 pts")
+   (interface
+    (sequence in)
+    (sequence out)
+    (output 1
+     (type data)
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component count 256)
+   )
+   (views
+    (icon
+     (origin 61 198)
+     (extent 78 64)
+     (iconImage "/usr/lib/veetest/bitmaps/loop.icon")
+    )
+    (detail
+     (origin 88 323)
+     (extent 165 34)
+    )
+    (active icon)
+   )
+  )
+  (component 14 "FromWaveform"
+   (name "UnBuild Waveform")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Wf Data")
+     (requires
+      (datatype Waveform)
+     )
+     (lock name constraints)
+    )
+    (output 1
+     (type data)
+     (name "Real Ary")
+     (lock name constraints)
+    )
+    (output 2
+     (type data)
+     (name "Interval")
+     (lock name constraints)
+    )
+   )
+   (implementation
+   )
+   (views
+    (icon
+     (origin 223 308)
+     (extent 154 25)
+    )
+    (detail
+     (origin 305 505)
+     (extent 80 70)
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 15 "Counter"
+   (name "Counter")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Data")
+    )
+    (output 1
+     (type data)
+     (name "Count")
+     (tag "Count")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component clearAtPrerun 1)
+    (component clearAtActivate 1)
+   )
+   (views
+    (icon
+     (origin 171 308)
+     (extent 78 25)
+    )
+    (detail
+     (origin 185 253)
+     (extent 150 34)
+    )
+    (active detail)
+   )
+  )
+  (component 16 "Formula"
+   (name "x(n)")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "A")
+     (optional yes)
+    )
+    (input 2
+     (type data)
+     (name "B")
+     (optional yes)
+    )
+    (output 1
+     (type data)
+     (name "Result")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component isLocked no)
+    (component expr 1 "b[a]")
+   )
+   (views
+    (icon
+     (origin 417 268)
+     (extent 46 25)
+    )
+    (detail
+     (origin 467 408)
+     (extent 79 104)
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 17 "VFunctionGenerator"
+   (name "200Hz Square Wave")
+   (interface
+    (sequence in)
+    (sequence out)
+    (output 1
+     (type data)
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component function Square)
+    (component frequency 200)
+    (component amplitude 1)
+    (component dcOffset 0)
+    (component phaseShift 0)
+    (component numPoints 256)
+    (component interval 0.02)
+    (component degRad Deg)
+    (component errorOnAlias 1)
+   )
+   (views
+    (icon
+     (origin 19 308)
+     (extent 163 25)
+    )
+    (detail
+     (origin 31 441)
+     (extent 239 198)
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
   (configuration
-   (connect D10:1 D0:1)
-   (connect D8:1 D0:2)
-   (connect D4:1 D2:1)
-   (connect D12:1 D4:1)
-   (connect D9:1 D4:2)
-   (connect D4:1 D6:1)
-   (connect D2:1 D6:2)
-   (connect D2:2 D6:3)
-   (connect D2:3 D6:4)
-   (connect D5:1 D6:5)
-   (connect D6:1 D7:1)
-   (connect D7:1 D8:1)
-   (connect D2:1 D9:1)
-   (connect D2:2 D9:2)
-   (connect D2:3 D9:3)
-   (connect D3:1 D9:4)
+   (connect D17:1 D0:1)
+   (connect D3:1 D0:2)
+   (connect D16:1 D2:1)
+   (connect D4:1 D2:2)
+   (connect D11:1 D3:1)
+   (connect D7:1 D4:1)
+   (connect D7:2 D4:2)
+   (connect D7:3 D4:3)
+   (connect D8:1 D4:4)
+   (connect D0:0 D6:0)
+   (connect D2:1 D7:1)
+   (connect D2:1 D10:1)
+   (connect D7:1 D10:2)
+   (connect D7:2 D10:3)
+   (connect D7:3 D10:4)
+   (connect D9:1 D10:5)
    (connect D10:1 D11:1)
-   (connect D14:1 D12:1)
-   (connect D11:1 D12:2)
-   (connect D13:0 D14:0)
+   (connect D5:0 D13:0)
+   (connect D17:1 D14:1)
+   (connect D13:1 D15:1)
+   (connect D13:1 D16:1)
+   (connect D14:1 D16:2)
   )
  )
  (views
   (detail
    (origin 0 67)
-   (extent 979 648)
+   (extent 1004 664)
    (configuration
-    (connect D10:1 D0:1
-     (Point 174 300)
-     (Point 180 300)
-     (Point 180 290)
-     (Point 460 290)
-     (Point 460 350)
+    (connect D17:1 D0:1
+     (Point 184 320)
+     (Point 200 320)
+     (Point 200 350)
      (Point 545 350)
     )
-    (connect D8:1 D0:2
+    (connect D3:1 D0:2
      (Point 530 530)
      (Point 545 530)
     )
-    (connect D4:1 D2:1
-     (Point 475 430)
-     (Point 490 430)
-     (Point 490 370)
-     (Point 10 370)
-     (Point 10 440)
-     (Point 34 440)
+    (connect D16:1 D2:1
+     (Point 465 280)
+     (Point 480 280)
+     (Point 480 310)
+     (Point 410 310)
+     (Point 410 400)
+     (Point 424 400)
     )
-    (connect D12:1 D4:1
-     (Point 435 320)
-     (Point 450 320)
-     (Point 450 350)
-     (Point 410 350)
-     (Point 410 420)
+    (connect D4:1 D2:2
+     (Point 361 420)
      (Point 424 420)
     )
-    (connect D9:1 D4:2
-     (Point 361 440)
-     (Point 424 440)
-    )
-    (connect D4:1 D6:1
-     (Point 475 430)
-     (Point 490 430)
-     (Point 490 460)
-     (Point 380 460)
-     (Point 380 490)
-     (Point 360 490)
-     (Point 360 540)
-     (Point 120 540)
-     (Point 120 570)
-     (Point 148 570)
-    )
-    (connect D2:1 D6:2
-     (Point 186 420)
-     (Point 200 420)
-     (Point 200 380)
-     (Point 20 380)
-     (Point 20 500)
-     (Point 110 500)
-     (Point 110 580)
-     (Point 148 580)
-    )
-    (connect D2:2 D6:3
-     (Point 186 440)
-     (Point 200 440)
-     (Point 200 430)
-     (Point 220 430)
-     (Point 220 510)
-     (Point 140 510)
-     (Point 140 590)
-     (Point 148 590)
-    )
-    (connect D2:3 D6:4
-     (Point 186 460)
-     (Point 200 460)
-     (Point 200 500)
-     (Point 130 500)
-     (Point 130 600)
-     (Point 148 600)
-    )
-    (connect D5:1 D6:5
-     (Point 85 600)
-     (Point 100 600)
-     (Point 100 610)
-     (Point 148 610)
-    )
-    (connect D6:1 D7:1
-     (Point 231 590)
-     (Point 252 590)
-    )
-    (connect D7:1 D8:1
-     (Point 367 590)
-     (Point 380 590)
-     (Point 380 580)
+    (connect D11:1 D3:1
+     (Point 497 630)
+     (Point 510 630)
+     (Point 510 580)
      (Point 370 580)
      (Point 370 530)
      (Point 389 530)
     )
-    (connect D2:1 D9:1
-     (Point 186 420)
+    (connect D7:1 D4:1
+     (Point 187 400)
+     (Point 278 400)
+    )
+    (connect D7:2 D4:2
+     (Point 187 410)
+     (Point 278 410)
+    )
+    (connect D7:3 D4:3
+     (Point 187 420)
      (Point 278 420)
     )
-    (connect D2:2 D9:2
-     (Point 186 440)
-     (Point 200 440)
-     (Point 200 430)
+    (connect D8:1 D4:4
+     (Point 196 520)
+     (Point 220 520)
+     (Point 220 430)
      (Point 278 430)
     )
-    (connect D2:3 D9:3
-     (Point 186 460)
-     (Point 210 460)
-     (Point 210 440)
-     (Point 278 440)
+    (connect D0:0 D6:0
+     (Point 770 625)
+     (Point 770 655)
     )
-    (connect D3:1 D9:4
-     (Point 95 530)
-     (Point 230 530)
-     (Point 230 450)
-     (Point 278 450)
+    (connect D2:1 D7:1
+     (Point 475 410)
+     (Point 490 410)
+     (Point 490 360)
+     (Point 20 360)
+     (Point 20 410)
+     (Point 32 410)
+    )
+    (connect D2:1 D10:1
+     (Point 475 410)
+     (Point 490 410)
+     (Point 490 480)
+     (Point 270 480)
+     (Point 270 610)
+     (Point 278 610)
+    )
+    (connect D7:1 D10:2
+     (Point 187 400)
+     (Point 260 400)
+     (Point 260 370)
+     (Point 380 370)
+     (Point 380 470)
+     (Point 260 470)
+     (Point 260 620)
+     (Point 278 620)
+    )
+    (connect D7:2 D10:3
+     (Point 187 410)
+     (Point 250 410)
+     (Point 250 630)
+     (Point 278 630)
+    )
+    (connect D7:3 D10:4
+     (Point 187 420)
+     (Point 240 420)
+     (Point 240 640)
+     (Point 278 640)
+    )
+    (connect D9:1 D10:5
+     (Point 195 650)
+     (Point 278 650)
     )
     (connect D10:1 D11:1
-     (Point 174 300)
-     (Point 180 300)
-     (Point 180 320)
-     (Point 200 320)
+     (Point 361 630)
+     (Point 382 630)
     )
-    (connect D14:1 D12:1
-     (Point 141 240)
-     (Point 370 240)
-     (Point 370 310)
-     (Point 384 310)
-    )
-    (connect D11:1 D12:2
-     (Point 359 310)
-     (Point 370 310)
-     (Point 370 330)
-     (Point 384 330)
-    )
-    (connect D13:0 D14:0
+    (connect D5:0 D13:0
      (Point 100 183)
-     (Point 100 225)
+     (Point 100 195)
+    )
+    (connect D17:1 D14:1
+     (Point 184 320)
+     (Point 220 320)
+    )
+    (connect D13:1 D15:1
+     (Point 141 230)
+     (Point 160 230)
+     (Point 160 270)
+     (Point 182 270)
+    )
+    (connect D13:1 D16:1
+     (Point 141 230)
+     (Point 160 230)
+     (Point 160 210)
+     (Point 360 210)
+     (Point 360 270)
+     (Point 414 270)
+    )
+    (connect D14:1 D16:2
+     (Point 379 310)
+     (Point 400 310)
+     (Point 400 290)
+     (Point 414 290)
     )
    )
   )
